@@ -120,11 +120,16 @@ def run_regression(X, y, Constraints={}, report=True, explicit_intercept=False):
     # Constraints['coefficients'] is a matrix of row-wise coefficients defining contrast scores.
     # Constraints['constants'] is a vector of constants for the contrasts.
     O = {}
+    if len(y.shape) > 0:
+        y = y.reshape(len(y))
+    if len(X.shape) == 1:
+        X = X.reshape((len(X), 1))
     # Add intercept to X
     if not explicit_intercept:
         intercept_v = np.array([1 for x in range(X.shape[0])]).reshape(X.shape[0], 1)
         X = np.hstack([X, intercept_v])
         if not len(Constraints) == 0:
+            Constraints = Constraints.copy()
             CM = Constraints['coefficients']
             constraint_column = np.array([0 for x in range(CM.shape[0])]).reshape(CM.shape[0], 1)
             Constraints['coefficients'] = np.hstack([Constraints['coefficients'], constraint_column])
